#!/bin/sh
#
#  COPYRIGHT (C) 2019 MITSUBISHI ELECTRIC CORPORATION
#  ALL RIGHTS RESERVED
#
#  Uninstall Printer Driver Script
#  For MITSUBISHI CPD80D Digital Color Printer
#  Ver.2.00 for macOS
#


TARGET_DIR_VENDOR="MITSUBISHI"
TARGET_DIR_ICONS="Icons"
TARGET_DIR_FILTER="filter"
TARGET_PPD="CP80.ppd.gz"
TARGET_ICON="CP80.icns"
TARGET_FILTER="CP80Filter"
TARGET_FILTER1="CP80comFilter"
TARGET_LUTDATA1="CPD80L01.lut"
TARGET_CPCDATA1="CPD80N01.cpc"
TARGET_CPCDATA2="CPD80S01.cpc"
TARGET_CPCDATA3="CPD80U01.cpc"
TARGET_CPCDATA4="CPD80E01.cpc"
TARGET_MATDATA1="D80MAT01.raw"
TARGET_PKG_ID="com.mitsubishi.CP80"

rm_printer() {
    for model in $*
    do
      /usr/sbin/lpadmin -x $model 2> /dev/null
    done
    return 0
}

remove_file() {
    for file in $*
    do
        if [ -f "$file" ]; then
            sudo rm -f "$file"
            if [ $? != 0 ]; then
                return 1
            fi
        fi
    done
    return 0
}

remove_dir() {
    if [ -d "$*" ]; then
        sudo rm -rf "$*"
        if [ $? != 0 ]; then
            return 1
        fi
    fi
    return 0
}

remove_emptydir() {
    if [ -d $* ]; then
        local isEmpty=1
        for file in $(ls "$*"); do
            local isEmpty=0
            break
        done
        if [ $isEmpty = 1 ]; then
            sudo rm -rf "$*"
            if [ $? != 0 ]; then
                return 1
            fi
        fi
    fi
    return 0
}

remove_driver() {
    if remove_file $(find /Library/Printers/PPDs -name "$TARGET_PPD"); then :; else
        return 1
    fi
    if remove_file "/Library/Printers/$TARGET_DIR_VENDOR/$TARGET_DIR_ICONS/$TARGET_ICON"; then :; else
        return 1
    fi
    if remove_emptydir "/Library/Printers/$TARGET_DIR_VENDOR/$TARGET_DIR_ICONS"; then :; else
        return 1
    fi
    if remove_file "/Library/Printers/$TARGET_DIR_VENDOR/$TARGET_DIR_FILTER/$TARGET_FILTER"; then :; else
        return 1
    fi
    if remove_file "/Library/Printers/$TARGET_DIR_VENDOR/$TARGET_DIR_FILTER/$TARGET_FILTER1"; then :; else
        return 1
    fi
    if remove_file "/Library/Printers/$TARGET_DIR_VENDOR/$TARGET_DIR_FILTER/$TARGET_LUTDATA1"; then :; else
        return 1
    fi
    if remove_file "/Library/Printers/$TARGET_DIR_VENDOR/$TARGET_DIR_FILTER/$TARGET_CPCDATA1"; then :; else
        return 1
    fi
    if remove_file "/Library/Printers/$TARGET_DIR_VENDOR/$TARGET_DIR_FILTER/$TARGET_CPCDATA2"; then :; else
        return 1
    fi
    if remove_file "/Library/Printers/$TARGET_DIR_VENDOR/$TARGET_DIR_FILTER/$TARGET_CPCDATA3"; then :; else
        return 1
    fi
    if remove_file "/Library/Printers/$TARGET_DIR_VENDOR/$TARGET_DIR_FILTER/$TARGET_CPCDATA4"; then :; else
        return 1
    fi
    if remove_file "/Library/Printers/$TARGET_DIR_VENDOR/$TARGET_DIR_FILTER/$TARGET_MATDATA1"; then :; else
        return 1
    fi
    if remove_emptydir "/Library/Printers/$TARGET_DIR_VENDOR/$TARGET_DIR_FILTER"; then :; else
        return 1
    fi
    if remove_emptydir "/Library/Printers/$TARGET_DIR_VENDOR"; then :; else
        return 1
    fi

    sudo pkgutil --forget $TARGET_PKG_ID > /dev/null 2>&1

    return 0
}

do_reboot() {
    echo "Uninstallation was completed."

    while true
    do
        echo "Is a computer rebooted?(Y/N): "
        read isReboot

        case "$isReboot" in
            "y" | "Y" )
                osascript -e 'tell application "System Events"' -e 'restart' -e 'end tell'
                break;;
            "n" | "N" )
                break;;
            * )
                ;;
        esac
    done
    return 0
}

rm_printer $(find /etc/cups/ppd -name "MITSUBISHI_CPD80D*.ppd" -exec basename {} .ppd \;)
if remove_driver; then
    do_reboot
else
    echo "Uninstallation went wrong."
fi

exit 0
